# -*- indent-tabs-mode: t -*-

# Soya 3D tutorial
# Copyright (C) 2004 Jean-Baptiste LAMY
# Copyright (C) 2008 Patrick Sabin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


# modeling-transparency-1: Transparency : semi-transparent cubes

# In this lesson, we'll build a semi-transparent cube.


# Imports and inits Soya.

import sys, os, os.path, soya, soya.cube

soya.init()
soya.path.append(os.path.join(os.path.dirname(sys.argv[0]), "data"))

# Creates the scene.

scene = soya.World()

# Creates a material, and set its diffuse color to a semi-transparent white (alpha = 0.5).
# See lesson modeling-material-1.py about materials and material colors.
# Similarly, you can use per-vertex semi-transparent colors.

texture = soya.Material(soya.Image.get("metal1.png"))

red = soya.Material();
red.diffuse = (1.0, 0.0, 0.0, 1.0)

green = soya.Material();
green.diffuse = (0.0, 1.0, 0.0, 1.0)

blue = soya.Material();
blue.diffuse = (0.0, 0.0, 1.0, 1.0)

transparent = soya.Material()
transparent.diffuse = (1.0, 1.0, 1.0, 0.5)

# Texture

m_cube_texture = soya.cube.Cube(material = texture).shapify()
m_cube_red = soya.cube.Cube(material = red).shapify()
m_cube_blue = soya.cube.Cube(material = blue).shapify()
m_cube_green = soya.cube.Cube(material = green).shapify()

# Transparent
cube_transparent = soya.cube.Cube(material = transparent)
for face in cube_transparent.children:
	face.double_sided = 1
cube_model = cube_transparent.to_model()


cube1 = soya.Body(scene, cube_model)
cube1.set_xyz(-0.3, 0.3, 0.0)
cube1.rotate_y(30.0)

cube2 = soya.Body(scene, cube_model)
cube2.set_xyz(0.0, 0.0, -1.5)
cube2.rotate_y(30.0)

cube3 = soya.Body(scene, cube_model)
cube3.set_xyz(0.6, -0.4, 0.5)
cube3.rotate_y(30.0)

cube_texture = soya.Body(scene, m_cube_texture)
cube_texture.set_xyz(-1.5, 0, 0)
cube_texture.rotate_y(30.0)

cube_red = soya.Body(scene, m_cube_red)
cube_red.set_xyz(1.5, 0, 0)
cube_red.rotate_y(30.0)

cube_blue = soya.Body(scene, m_cube_blue)
cube_blue.set_xyz(1.5, 1.5, 0)
cube_blue.rotate_y(30.0)

cube_green = soya.Body(scene, m_cube_green)
cube_green.set_xyz(-0.6, -0.5, 0.5)
cube_green.rotate_y(30.0)

# Creates a light.

light = soya.Light(scene)
light.set_xyz(1.0, 0.7, 1.0)

# Creates a camera.

camera = soya.Camera(scene)
camera.set_xyz(0.0, 0.0, 3.0)
soya.set_root_widget(camera)

soya.MainLoop(scene).main_loop()

