#!/usr/bin/env python

import sys, time, os, os.path, soya, soya.widget, Tkinter
from qt import *

class SoyaWindow(QWidget):
	def __init__(self, *args):
		QWidget.__init__(self, *args)
		self.setCaption("Soya Application")

		self.timer=QTimer()
		self.connect(self.timer, SIGNAL('timeout()'), self.update_soya)
		self.timer.start(30, 0)

		self.layout = QGridLayout(self, 3, 2, 5, 10)
		self.tsdisp = QTextEdit(self)
		self.tsdisp.setMinimumSize(300, 300)
		self.tsdisp.setTextFormat(Qt.PlainText)
		self.tscount = QLabel("", self)
		self.tscount.setFont(QFont("Sans", 24))
		self.forward = QPushButton("Move &Forward", self)
		self.backward= QPushButton("Move &Backward", self)
		self.quit = QPushButton("&Quit", self)
		self.layout.addMultiCellWidget(self.tsdisp, 0, 3, 0, 0)
		self.layout.addWidget(self.tscount, 0, 1)
		self.layout.addWidget(self.forward, 1, 1)
		self.layout.addWidget(self.backward, 2, 1)
		self.layout.addWidget(self.quit, 3, 1)
		self.connect(self.forward, SIGNAL("clicked()"),
			self.move_forward)
		self.connect(self.backward, SIGNAL("clicked()"),
			self.move_backward)
		self.connect(self.quit, SIGNAL("clicked()"),
			self.close)
	def update_soya(self):
		soya.MAIN_LOOP.update()
	def move_forward(self):
		head.y += 1
		stamp = time.ctime()
		self.tsdisp.append("forward: " + stamp)
		self.tscount.setText(str(self.tsdisp.lines()))
	def move_backward(self):
		head.y -= 1
		stamp = time.ctime()
		self.tsdisp.append("backward: " + stamp)
		self.tscount.setText(str(self.tsdisp.lines()))

if __name__ == "__main__":
	soya.init()
	soya.path.append(os.path.join(os.path.dirname(sys.argv[0]), "data"))

	scene = soya.World()
	head = soya.Body(scene, soya.Model.get("caterpillar_head"))

	light = soya.Light(scene)
	light.set_xyz(2.0, 5.0, 0.0)

	camera = soya.Camera(scene)
	camera.set_xyz(0.0, 15.0, 15.0)
	camera.look_at(head)

	# Creates a widget group, containing the camera and a label showing the FPS.
	soya.set_root_widget(soya.widget.Group())
	soya.root_widget.add(camera)
	soya.root_widget.add(soya.widget.FPSLabel())

	# Create the MainLoop, but DON'T start it (= don't call MainLoop.main_loop()).
	soya.MainLoop(scene)


	# Create a Qt window
	# When the button is clicked, the head moves up.

	app=QApplication(sys.argv)
	app.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
	w=SoyaWindow()

	app.setMainWidget(w)
	w.show()
	app.exec_loop()

